summaryrefslogtreecommitdiffstats
path: root/chromium/chrome/browser/ui/webui/help/version_updater_chromeos.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/chrome/browser/ui/webui/help/version_updater_chromeos.h')
-rw-r--r--chromium/chrome/browser/ui/webui/help/version_updater_chromeos.h16
1 files changed, 6 insertions, 10 deletions
diff --git a/chromium/chrome/browser/ui/webui/help/version_updater_chromeos.h b/chromium/chrome/browser/ui/webui/help/version_updater_chromeos.h
index 3ec09168b97..057881513d2 100644
--- a/chromium/chrome/browser/ui/webui/help/version_updater_chromeos.h
+++ b/chromium/chrome/browser/ui/webui/help/version_updater_chromeos.h
@@ -9,7 +9,6 @@
#include "base/macros.h"
#include "base/memory/weak_ptr.h"
#include "chrome/browser/ui/webui/help/version_updater.h"
-#include "chromeos/dbus/update_engine_client.h"
namespace content {
class BrowserContext;
@@ -26,6 +25,7 @@ class VersionUpdaterCros : public VersionUpdater,
bool is_powerwash_allowed) override;
void GetChannel(bool get_current_channel,
const ChannelCallback& callback) override;
+ void GetEolInfo(EolInfoCallback callback) override;
void SetUpdateOverCellularOneTimePermission(const StatusCallback& callback,
const std::string& update_version,
int64_t update_size) override;
@@ -33,8 +33,6 @@ class VersionUpdaterCros : public VersionUpdater,
// Gets the last update status, without triggering a new check or download.
void GetUpdateStatus(const StatusCallback& callback);
- void GetEolStatus(EolStatusCallback callback) override;
-
protected:
friend class VersionUpdater;
@@ -44,8 +42,7 @@ class VersionUpdaterCros : public VersionUpdater,
private:
// UpdateEngineClient::Observer implementation.
- void UpdateStatusChanged(
- const chromeos::UpdateEngineClient::Status& status) override;
+ void UpdateStatusChanged(const update_engine::StatusResult& status) override;
// Callback from UpdateEngineClient::RequestUpdateCheck().
void OnUpdateCheck(chromeos::UpdateEngineClient::UpdateCheckResult result);
@@ -57,10 +54,9 @@ class VersionUpdaterCros : public VersionUpdater,
void OnGetChannel(const ChannelCallback& cb,
const std::string& current_channel);
- // Callback from UpdateEngineClient::GetEolStatus().
- void OnGetEolStatus(EolStatusCallback cb,
- update_engine::EndOfLifeStatus status,
- base::Optional<int32_t> number_of_milestones);
+ // Callback from UpdateEngineClient::GetEolInfo().
+ void OnGetEolInfo(EolInfoCallback cb,
+ chromeos::UpdateEngineClient::EolInfo eol_info);
// BrowserContext in which the class was instantiated.
content::BrowserContext* context_;
@@ -69,7 +65,7 @@ class VersionUpdaterCros : public VersionUpdater,
StatusCallback callback_;
// Last state received via UpdateStatusChanged().
- chromeos::UpdateEngineClient::UpdateStatusOperation last_operation_;
+ update_engine::Operation last_operation_;
// True if an update check should be scheduled when the update engine is idle.
bool check_for_update_when_idle_;